package cn.wisenergy.service.app.impl;

import cn.wisenergy.common.utils.R;
import cn.wisenergy.mapper.*;
import cn.wisenergy.model.app.*;
import cn.wisenergy.model.dto.UsersInfoDto;
import cn.wisenergy.model.vo.UserVo;
import cn.wisenergy.service.app.UserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * @author 86187
 * @ Description: 用户接口实现
 * @ Author     : 86187
 * @ Date       : 2021/1/6 16:11
 */
@Service
@Slf4j
public class UserServiceImpl extends ServiceImpl<UsersMapper, Users> implements UserService {

    @Resource
    private UsersMapper usersMapper;

    @Resource
    private ActivesMapper activesMapper;

    @Resource
    private UserRechargeMapper userRechargeMapper;

    @Resource
    private UserWithdrawsMapper withdrawsMapper;

    @Resource
    private UsdtOrderDetailsMapper orderDetailsMapper;

    @Resource
    private UserDataMapper userDataMapper;

    @Override
    public Users getById(Long userId) {
        return usersMapper.getById(userId);
    }

    @Override
    public R<List<UserVo>> getLastUser(Long userId) {
        //用户id为空时，查询最顶级
        if (null == userId) {
            userId = 1L;
            Users users = usersMapper.getById(userId);
            UserVo userVo = new UserVo();
            userVo.setUserId(users.getId());
            userVo.setParentId(users.getParentId());
            userVo.setRealName(null);

            List<UserVo> list = new ArrayList<>();
            list.add(userVo);
            return R.ok(list);
        }

        //id不为空,查询当前用户的下一级
        Users user = usersMapper.getById(userId);
        List<UserVo> lastList = usersMapper.getLastUser(Integer.valueOf(user.getId().toString()));
        return R.ok(lastList);
    }

    @Override
    public R<UsersInfoDto> getByUserInfoById(Long userId) {
        if (null == userId) {
            return R.error("入参不能为空!");
        }

        UsersInfoDto userDto = new UsersInfoDto();

        //1、获取用户信息
        UserData user = userDataMapper.getByUserId(userId);
        if (null != user) {
            userDto.setUserId(user.getUserId());
            userDto.setPhone(user.getPhone());
            userDto.setRank(user.getRank());
            userDto.setIdNumber(user.getIdNumber());
            userDto.setRealName(user.getRealName());
            userDto.setBottom(user.getRank());
            userDto.setTotalPeople(user.getTotalPeople());
            userDto.setTotalWithdrawal(String.valueOf(user.getTotalWithdrawal()));
            userDto.setBuyTotal(String.valueOf(user.getBuyTotal()));
            userDto.setSaleTotal(String.valueOf(user.getSaleTotal()));
        }
        return R.ok(userDto);
    }

}
